searchData={"items":[{"type":"module","title":"EDTF","doc":"Parse, validate, and humanize EDTF date strings","ref":"EDTF.html"},{"type":"function","title":"EDTF.humanize/1","doc":"Humanize an EDTF date string\n\nExample:\n  ```elixir\n  iex> humanize(\"1999-06-10\")\n  \"June 10, 1999\"\n\n  iex> humanize(\"bad date!\")\n  {:error, :invalid_format}\n  ```","ref":"EDTF.html#humanize/1"},{"type":"function","title":"EDTF.parse/1","doc":"Parse an EDTF date string\n\nExample:\n  ```elixir\n  iex> parse(\"1999-06-10\")\n  {:ok, %EDTF.Date{level: 0, type: :date, values: [1999, 5, 10]}}\n\n  iex> parse(\"bad date!\")\n  {:error, :invalid_format}\n  ```","ref":"EDTF.html#parse/1"},{"type":"function","title":"EDTF.validate/1","doc":"Validate an EDTF date string\n\nExample:\n  ```elixir\n  iex> validate(\"1999-06-10\")\n  {:ok, \"1999-06-10\"}\n\n  iex> validate(\"bad date!\")\n  {:error, :invalid_format}\n  ```","ref":"EDTF.html#validate/1"},{"type":"module","title":"EDTF.Aggregate","doc":"Parser for EDTF Lists and Sets","ref":"EDTF.Aggregate.html"},{"type":"function","title":"EDTF.Aggregate.assemble/1","doc":"","ref":"EDTF.Aggregate.html#assemble/1"},{"type":"type","title":"EDTF.Aggregate.t/0","doc":"","ref":"EDTF.Aggregate.html#t:t/0"},{"type":"module","title":"EDTF.Continuation","doc":"EDTF Continuation Struct","ref":"EDTF.Continuation.html"},{"type":"type","title":"EDTF.Continuation.t/0","doc":"","ref":"EDTF.Continuation.html#t:t/0"},{"type":"module","title":"EDTF.Date","doc":"Parser for basic EDTF dates, including year, and decade","ref":"EDTF.Date.html"},{"type":"function","title":"EDTF.Date.assemble/1","doc":"","ref":"EDTF.Date.html#assemble/1"},{"type":"type","title":"EDTF.Date.edtf_attribute/0","doc":"","ref":"EDTF.Date.html#t:edtf_attribute/0"},{"type":"type","title":"EDTF.Date.edtf_type/0","doc":"","ref":"EDTF.Date.html#t:edtf_type/0"},{"type":"type","title":"EDTF.Date.t/0","doc":"","ref":"EDTF.Date.html#t:t/0"},{"type":"module","title":"EDTF.Humanize","doc":"Convert EDTF dates to human readable form","ref":"EDTF.Humanize.html"},{"type":"function","title":"EDTF.Humanize.humanize/1","doc":"","ref":"EDTF.Humanize.html#humanize/1"},{"type":"module","title":"EDTF.Humanize.Aggregate","doc":"Humanize EDTF Set and List types","ref":"EDTF.Humanize.Aggregate.html"},{"type":"function","title":"EDTF.Humanize.Aggregate.humanize/1","doc":"","ref":"EDTF.Humanize.Aggregate.html#humanize/1"},{"type":"module","title":"EDTF.Humanize.Date","doc":"Humanize EDTF Date, Year, Decade, Century, and Season types","ref":"EDTF.Humanize.Date.html"},{"type":"function","title":"EDTF.Humanize.Date.humanize/1","doc":"","ref":"EDTF.Humanize.Date.html#humanize/1"},{"type":"module","title":"EDTF.Infinity","doc":"EDTF Infinity struct","ref":"EDTF.Infinity.html"},{"type":"type","title":"EDTF.Infinity.t/0","doc":"","ref":"EDTF.Infinity.html#t:t/0"},{"type":"module","title":"EDTF.Interval","doc":"Parser for EDTF Intervals","ref":"EDTF.Interval.html"},{"type":"function","title":"EDTF.Interval.assemble/1","doc":"","ref":"EDTF.Interval.html#assemble/1"},{"type":"type","title":"EDTF.Interval.t/0","doc":"","ref":"EDTF.Interval.html#t:t/0"},{"type":"module","title":"EDTF.Level","doc":"Utility functions to add the correct level to `%EDTF.Date` structs","ref":"EDTF.Level.html"},{"type":"function","title":"EDTF.Level.add_level/1","doc":"","ref":"EDTF.Level.html#add_level/1"},{"type":"module","title":"EDTF.Parser","doc":"NimbleParsec parser for EDTF dates","ref":"EDTF.Parser.html"},{"type":"function","title":"EDTF.Parser.parse/2","doc":"Parses the given `binary` as parse.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the parse (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"EDTF.Parser.html#parse/2"},{"type":"function","title":"Options - EDTF.Parser.parse/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"EDTF.Parser.html#parse/2-options"},{"type":"module","title":"EDTF.Parser.Helpers","doc":"Helper functions for parsing EDTF dates","ref":"EDTF.Parser.Helpers.html"},{"type":"function","title":"EDTF.Parser.Helpers.apply_qualifier/5","doc":"Apply a parsed qualifier to a single value.\n\nExample:\n  ```elixir\n  iex> apply_qualifier(\"\", [value: 2000, qualifier: ~c\"%\"], %{}, nil, nil)\n  {\"\", [attributes: [approximate: true, uncertain: true], value: 2000], %{}}\n\n  iex> apply_qualifier(\"\", [value: 2000], %{}, nil, nil)\n  {\"\", [attributes: [], value: 2000], %{}}\n  ```","ref":"EDTF.Parser.Helpers.html#apply_qualifier/5"},{"type":"function","title":"EDTF.Parser.Helpers.apply_sign/5","doc":"Apply a parsed sign to a parsed integer value.\n\nExample:\n  ```elixir\n  iex> apply_sign(\"\", [value: 2000, sign: ~c\"-\"], %{}, nil, nil)\n  {\"\", [value: -2000], %{}}\n\n  iex> apply_sign(\"\", [value: 2000], %{}, nil, nil)\n  {\"\", [value: 2000], %{}}\n  ```","ref":"EDTF.Parser.Helpers.html#apply_sign/5"},{"type":"function","title":"EDTF.Parser.Helpers.bitmask/4","doc":"","ref":"EDTF.Parser.Helpers.html#bitmask/4"},{"type":"function","title":"EDTF.Parser.Helpers.bitmask/6","doc":"Calculate the appropriate qualifier bitmasks for a given YYYY, MM, or DD. Bits\nare calculated from the left and shifted left to account for the specific\ncomponent.\n\n- The digits of YYYY are 1, 2, 4, 8\n- The digits of MM are 16, 32\n- The digits of DD are 64, 128\n\nA full component qualifier (leading `~`, `?`, or `%`) results in the component\nbeing fully masked (15 for year, 48 for month, or 192 for day). Unspecified digits\n(`X`) flip individual bits.\n\nExample:\n  ```elixir\n  iex> bitmask(\"-%02\", [value: ~c\"200X\", sign: ~c\"-\"], %{}, nil, nil, 0)\n  {\"-%02\", [[value: -2000, attributes: [unspecified: 8]]], %{}}\n\n  iex> bitmask(\"\", [value: ~c\"02\", qualifier: ~c\"%\"], %{}, nil, nil, 4)\n  {\"\", [[value: 2, attributes: [approximate: 48, uncertain: 48]]], %{}}\n  ```","ref":"EDTF.Parser.Helpers.html#bitmask/6"},{"type":"function","title":"EDTF.Parser.Helpers.reduce/5","doc":"Reduce a list of components and bitmasks to a single list of values with\ntheir mask attributes ORed together.\n\nExample:\n  ```elixir\n  iex> reduce(\"\", [\n  ...>   [value: 10, attributes: [unspecified: 128]],\n  ...>   [value: 1, attributes: [unspecified: 32]],\n  ...>   [value: 0, attributes: [unspecified: 5]]\n  ...> ], %{}, nil, nil)\n  {\"\", [values: [0, 1, 10], attributes: [unspecified: 165]], %{}}\n\n  iex> reduce(\"\", [\n  ...>   [value: 10, attributes: [unspecified: 128]],\n  ...>   [value: 1, attributes: [approximate: 48]],\n  ...>   [value: 0, attributes: [approximate: 15, uncertain: 15]]\n  ...> ], %{}, nil, nil)\n  {\"\", [values: [0, 1, 10], attributes: [unspecified: 128, approximate: 63, uncertain: 15]], %{}}","ref":"EDTF.Parser.Helpers.html#reduce/5"},{"type":"function","title":"EDTF.Parser.Helpers.to_integer/5","doc":"Convert a parsed numeric bitstring to an integer\n\nExample:\n  ```elixir\n  iex> to_integer(\"\", ~c\"4321\", %{}, nil, nil)\n  {\"\", [1234], %{}}","ref":"EDTF.Parser.Helpers.html#to_integer/5"},{"type":"extras","title":"EDTF","doc":"# EDTF\n\n[![Build](https://github.com/nulib/edtf_ex/actions/workflows/build.yml/badge.svg)](https://github.com/nulib/edtf_ex/actions/workflows/build.yml)\n[![Coverage](https://coveralls.io/repos/github/nulib/edtf_ex/badge.svg?branch=main)](https://coveralls.io/github/nulib/edtf_ex?branch=main)\n[![Hex.pm](https://img.shields.io/hexpm/v/edtf.svg)](https://hex.pm/packages/edtf)\n\nAn Extended Date Time Format (EDTF) / ISO 8601-2 parser and English language rendering\ntoolkit for Elixir.","ref":"readme.html"},{"type":"extras","title":"Compatibility - EDTF","doc":"","ref":"readme.html#compatibility"},{"type":"extras","title":"EDTF / ISO 8601-2 - EDTF","doc":"EDTF fully implements [EDTF](http://www.loc.gov/standards/datetime)\nlevels 0, 1, and 2 as specified by ISO 8601-2","ref":"readme.html#edtf-iso-8601-2"},{"type":"extras","title":"Installation - EDTF","doc":"Add `edtf` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:edtf, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - EDTF","doc":"See `EDTF.parse/1`, `EDTF.validate/1`, and `EDTF.humanize/1`.","ref":"readme.html#usage"},{"type":"extras","title":"Notes - EDTF","doc":"- Some human-readable dates containing Level 2 qualifications and years with significant digits, \n  may produce less specific results than desired.","ref":"readme.html#notes"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}